diff --git a/oscar/SleepLib/common.cpp b/oscar/SleepLib/common.cpp
index ee3bb501..927fa3ac 100644
--- a/oscar/SleepLib/common.cpp
+++ b/oscar/SleepLib/common.cpp
@@ -427,7 +427,7 @@ QString STR_TR_Sessions;
QString STR_TR_PrRelief; // Pressure Relief
QString STR_TR_Bookmarks;
-QString STR_TR_OSCR;
+QString STR_TR_OSCAR;
QString STR_TR_AppVersion;
QString STR_TR_Default;
@@ -632,7 +632,7 @@ void initializeStrings()
STR_TR_PrRelief = QObject::tr("Pr. Relief"); // Pressure Relief
STR_TR_Bookmarks = QObject::tr("Bookmarks");
- STR_TR_OSCR = QObject::tr("OSCR");
+ STR_TR_OSCAR = QObject::tr("OSCAR");
STR_TR_AppVersion = QObject::tr("v%1").arg(VersionString);
STR_TR_Mode = QObject::tr("Mode");
diff --git a/oscar/SleepLib/common.h b/oscar/SleepLib/common.h
index c91f5380..737ff223 100644
--- a/oscar/SleepLib/common.h
+++ b/oscar/SleepLib/common.h
@@ -164,9 +164,9 @@ const QString STR_MACH_ZEO = "Zeo";
const QString STR_PREF_Language = "Language";
-const QString STR_AppName = "OSCR";
+const QString STR_AppName = "OSCAR";
const QString STR_DeveloperName = "NightOwl";
-const QString STR_AppRoot = "OSCR_Data";
+const QString STR_AppRoot = "OSCAR_Data";
///////////////////////////////////////////////////////////////////////////////////////////////
// Commonly used translatable text strings
@@ -326,7 +326,7 @@ extern QString STR_TR_PrRelief; // Pressure Relief
extern QString STR_TR_SensAwake;
extern QString STR_TR_Bookmarks;
-extern QString STR_TR_OSCR;
+extern QString STR_TR_OSCAR;
extern QString STR_TR_AppVersion;
extern QString STR_TR_Mode;
diff --git a/oscar/SleepLib/day.cpp b/oscar/SleepLib/day.cpp
index 3bf6fe80..fbbb13e3 100644
--- a/oscar/SleepLib/day.cpp
+++ b/oscar/SleepLib/day.cpp
@@ -107,7 +107,7 @@ void Day::addSession(Session *s)
auto mi = machines.find(s->type());
if (mi != machines.end()) {
if (mi.value() != s->machine()) {
- qDebug() << "OSCR can't add session" << s->session() << "to this day record, as it already contains a different machine of the same MachineType";
+ qDebug() << "OSCAR can't add session" << s->session() << "to this day record, as it already contains a different machine of the same MachineType";
return;
}
} else {
diff --git a/oscar/SleepLib/journal.cpp b/oscar/SleepLib/journal.cpp
index d9feb36f..979d9f0a 100644
--- a/oscar/SleepLib/journal.cpp
+++ b/oscar/SleepLib/journal.cpp
@@ -22,7 +22,7 @@ JournalEntry::JournalEntry(QDate date)
{
Machine * jmach = p_profile->GetMachine(MT_JOURNAL);
if (jmach == nullptr) { // Create Journal machine record if it doesn't already exist
- MachineInfo info(MT_JOURNAL,0, "Journal", QObject::tr("Journal Data"), QString(), QString(), QString(), QObject::tr("OSCR"), QDateTime::currentDateTime(), journal_data_version);
+ MachineInfo info(MT_JOURNAL,0, "Journal", QObject::tr("Journal Data"), QString(), QString(), QString(), QObject::tr("OSCAR"), QDateTime::currentDateTime(), journal_data_version);
// Using machine ID 1 rather than a random number, so in future, if profile.xml gets screwed up they'll get their data back..
// TODO: Perhaps search for unlinked journal folders here to save some anger and frustration? :P
@@ -40,18 +40,18 @@ JournalEntry::JournalEntry(QDate date)
machid = tmp.toUInt(&ok, 16);
if (!ok) {
QMessageBox::warning(nullptr, STR_MessageBox_Warning,
- QObject::tr("OSCR found an old Journal folder, but it looks like it's been renamed:")+"\n\n"+
+ QObject::tr("OSCAR found an old Journal folder, but it looks like it's been renamed:")+"\n\n"+
QString("%1").arg(dirs[0])+
- QObject::tr("OSCR will not touch this folder, and will create a new one instead.")+"\n\n"+
- QObject::tr("Please be careful when playing in OSCR's profile folders :-P"), QMessageBox::Ok);
+ QObject::tr("OSCAR will not touch this folder, and will create a new one instead.")+"\n\n"+
+ QObject::tr("Please be careful when playing in OSCAR's profile folders :-P"), QMessageBox::Ok);
// User renamed the folder.. report this
machid = 1;
}
if (journals > 1) {
QMessageBox::warning(nullptr, STR_MessageBox_Warning,
- QObject::tr("For some reason, OSCR couldn't find a journal object record in your profile, but did find multiple Journal data folders.\n\n")+
- QObject::tr("OSCR picked only the first one of these, and will use it in future:\n\n")+
+ QObject::tr("For some reason, OSCAR couldn't find a journal object record in your profile, but did find multiple Journal data folders.\n\n")+
+ QObject::tr("OSCAR picked only the first one of these, and will use it in future:\n\n")+
QString("%1").arg(dirs[0])+
QObject::tr("If your old data is missing, copy the contents of all the other Journal_XXXXXXX folders to this one manually."), QMessageBox::Ok);
// more then one.. report this.
@@ -208,7 +208,7 @@ void JournalEntry::delBookmark(qint64 start, qint64 end)
void BackupJournal(QString filename)
{
- QDomDocument doc("OSCR Journal");
+ QDomDocument doc("OSCAR Journal");
QDomElement droot = doc.createElement(STR_AppName);
doc.appendChild(droot);
diff --git a/oscar/SleepLib/loader_plugins/resmed_loader.cpp b/oscar/SleepLib/loader_plugins/resmed_loader.cpp
index 178f1335..dbec6e4f 100644
--- a/oscar/SleepLib/loader_plugins/resmed_loader.cpp
+++ b/oscar/SleepLib/loader_plugins/resmed_loader.cpp
@@ -1758,7 +1758,7 @@ int ResmedLoader::Open(const QString & dirpath)
// add primary STR.edf
strfiles.push_back(strpath);
- // Just in case we are importing into a new folder, process OSCR backup structures
+ // Just in case we are importing into a new folder, process OSCAR backup structures
dir.setPath(path + "STR_Backup");
dir.setFilter(QDir::Files | QDir::Hidden | QDir::Readable);
QFileInfoList flist = dir.entryInfoList();
@@ -2523,7 +2523,7 @@ bool ResmedLoader::LoadBRP(Session *sess, const QString & path)
return true;
}
-// Convert EDFSignal data to OSCR's Time-Delta Event format
+// Convert EDFSignal data to OSCAR's Time-Delta Event format
void ResmedLoader::ToTimeDelta(Session *sess, ResMedEDFParser &edf, EDFSignal &es, ChannelID code,
long recs, qint64 duration, EventDataType t_min, EventDataType t_max, bool square)
{
diff --git a/oscar/SleepLib/machine.cpp b/oscar/SleepLib/machine.cpp
index 1c797e92..d5c7a7cc 100644
--- a/oscar/SleepLib/machine.cpp
+++ b/oscar/SleepLib/machine.cpp
@@ -1105,7 +1105,7 @@ bool Machine::SaveSummaryCache()
qDebug() << "Saving" << info.brand << info.model << "Summaries";
QString filename = getDataPath() + summaryFileName;
- QDomDocument doc("OSCR_SessionIndex");
+ QDomDocument doc("OSCAR_SessionIndex");
QDomElement root = doc.createElement("sessions");
root.setAttribute("version", summaryxml_version);
diff --git a/oscar/SleepLib/profiles.cpp b/oscar/SleepLib/profiles.cpp
index 81fabd90..69cb1b46 100644
--- a/oscar/SleepLib/profiles.cpp
+++ b/oscar/SleepLib/profiles.cpp
@@ -506,17 +506,17 @@ void Profile::DataFormatError(Machine *m)
}
if (backups) {
- msg = msg + QObject::tr("OSCR maintains a backup of your devices data card that it uses for this purpose.")+ " " + release->notes[""] + " " + release->notes[platform] + " "+tr("Important:")+" "
diff --git a/oscar/aboutdialog.ui b/oscar/aboutdialog.ui
index 5ab5fcfb..58687b26 100644
--- a/oscar/aboutdialog.ui
+++ b/oscar/aboutdialog.ui
@@ -134,7 +134,7 @@
- OSCR is NOT a substitute for competent medical guidance from your Doctor.
";
+ msg = msg + QObject::tr("OSCAR maintains a backup of your devices data card that it uses for this purpose.")+ "
";
msg = msg + QObject::tr("Your old machine data should be regenerated provided this backup feature has not been disabled in preferences during a previous data import.") + "
";
backups = true;
} else {
- msg = msg + ""+STR_MessageBox_Warning+": "+QObject::tr("OSCR does not yet have any automatic card backups stored for this device.") + "
";
+ msg = msg + ""+STR_MessageBox_Warning+": "+QObject::tr("OSCAR does not yet have any automatic card backups stored for this device.") + "
";
msg = msg + QObject::tr("This means you will need to import this machine data again afterwards from your own backups or data card.") + "
";
}
msg += ""+QObject::tr("Important:")+" "+QObject::tr("Once you upgrade, you can not use this profile with the previous version anymore.")+"
"+
- QObject::tr("If you are concerned, click No to exit, and backup your profile manually, before starting OSCR again.")+ "
";
- msg = msg + ""+QObject::tr("Are you ready to upgrade, so you can run the new version of OSCR?")+"";
+ QObject::tr("If you are concerned, click No to exit, and backup your profile manually, before starting OSCAR again.")+ "
";
+ msg = msg + ""+QObject::tr("Are you ready to upgrade, so you can run the new version of OSCAR?")+"";
QMessageBox * question = new QMessageBox(QMessageBox::Warning, QObject::tr("Machine Database Changes"), msg, QMessageBox::Yes | QMessageBox::No);
@@ -530,7 +530,7 @@ void Profile::DataFormatError(Machine *m)
if (!m->Purge(3478216)) {
// Purge failed.. probably a permissions error.. let the user deal with it.
QMessageBox::critical(nullptr, STR_MessageBox_Error,
- QObject::tr("Sorry, the purge operation failed, which means this version of OSCR can't start.")+"\n\n"+
+ QObject::tr("Sorry, the purge operation failed, which means this version of OSCAR can't start.")+"\n\n"+
QObject::tr("The machine data folder needs to be removed manually.")+"\n\n"+
QObject::tr("This folder currently resides at the following location:")+"\n\n"+
QDir::toNativeSeparators(Get(p_preferences[STR_GEN_DataFolder].toString())), QMessageBox::Ok);
@@ -543,14 +543,14 @@ void Profile::DataFormatError(Machine *m)
if (!p_profile->session->backupCardData()) {
// Automatic backups not available for Intellipap users yet, so don't taunt them..
if (m->loaderName() != STR_MACH_Intellipap) {
- if (QMessageBox::question(nullptr, STR_MessageBox_Question, QObject::tr("Would you like to switch on automatic backups, so next time a new version of OSCR needs to do so, it can rebuild from these?"),
+ if (QMessageBox::question(nullptr, STR_MessageBox_Question, QObject::tr("Would you like to switch on automatic backups, so next time a new version of OSCAR needs to do so, it can rebuild from these?"),
QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes)) {
p_profile->session->setBackupCardData(true);
}
}
}
QMessageBox::information(nullptr, STR_MessageBox_Information,
- QObject::tr("OSCR will now start the import wizard so you can reinstall your %1 data.").arg(m->brand())
+ QObject::tr("OSCAR will now start the import wizard so you can reinstall your %1 data.").arg(m->brand())
,QMessageBox::Ok, QMessageBox::Ok);
mainwin->startImportDialog();
}
@@ -560,9 +560,9 @@ void Profile::DataFormatError(Machine *m)
} else {
delete question;
QMessageBox::information(nullptr, STR_MessageBox_Information,
- QObject::tr("OSCR will now exit, then (attempt to) launch your computers file manager so you can manually back your profile up:")+"\n\n"+
+ QObject::tr("OSCAR will now exit, then (attempt to) launch your computers file manager so you can manually back your profile up:")+"\n\n"+
QDir::toNativeSeparators(Get(p_preferences[STR_GEN_DataFolder].toString()))+"\n\n"+
- QObject::tr("Use your file manager to make a copy of your profile directory, then afterwards, restart OSCR and complete the upgrade process.")
+ QObject::tr("Use your file manager to make a copy of your profile directory, then afterwards, restart OSCAR and complete the upgrade process.")
, QMessageBox::Ok, QMessageBox::Ok);
showInGraphicalShell(Get(p_preferences[STR_GEN_DataFolder].toString()));
@@ -990,7 +990,7 @@ Profile *Create(QString name)
Machine *m = new Machine(p_profile, 0);
m->setType(MT_JOURNAL);
- MachineInfo info(MT_JOURNAL, 0, STR_MACH_Journal, "OSCR", STR_MACH_Journal, QString(), m->hexid(), QString(), QDateTime::currentDateTime(), 0);
+ MachineInfo info(MT_JOURNAL, 0, STR_MACH_Journal, "OSCAR", STR_MACH_Journal, QString(), m->hexid(), QString(), QDateTime::currentDateTime(), 0);
m->setInfo(info);
p_profile->AddMachine(m);
@@ -1016,7 +1016,7 @@ void saveProfileList()
QDomElement root = doc.createElement("profiles");
doc.appendChild(root);
- root.appendChild(doc.createComment("This file is created during Profile Scan for cloud access convenience, it's not used by Desktop version of OSCR."));
+ root.appendChild(doc.createComment("This file is created during Profile Scan for cloud access convenience, it's not used by Desktop version of OSCAR."));
for (auto it = profiles.begin(); it != profiles.end(); ++it) {
QDomElement elem = doc.createElement("profile");
diff --git a/oscar/SleepLib/schema.cpp b/oscar/SleepLib/schema.cpp
index efbe72a4..d6b7fbf0 100644
--- a/oscar/SleepLib/schema.cpp
+++ b/oscar/SleepLib/schema.cpp
@@ -172,13 +172,13 @@ void init()
QObject::tr("SensAwake"),QObject::tr("SensAwake feature will reduce pressure when waking is detected."),QObject::tr("SA"), STR_UNIT_EventsPerHour, DEFAULT, COLOR_Gold));
schema::channel.add(GRP_CPAP, new Channel(CPAP_UserFlag1 = 0x101e, FLAG, MT_CPAP, SESSION, "UserFlag1",
- QObject::tr("User Flag #1"), QObject::tr("A user definable event detected by OSCR's flow waveform processor."), QObject::tr("UF1"), STR_UNIT_EventsPerHour, DEFAULT, QColor(0xc0,0xc0,0xe0)));
+ QObject::tr("User Flag #1"), QObject::tr("A user definable event detected by OSCAR's flow waveform processor."), QObject::tr("UF1"), STR_UNIT_EventsPerHour, DEFAULT, QColor(0xc0,0xc0,0xe0)));
schema::channel.add(GRP_CPAP, new Channel(CPAP_UserFlag2 = 0x101f, FLAG, MT_CPAP, SESSION, "UserFlag2",
- QObject::tr("User Flag #2"),QObject::tr("A user definable event detected by OSCR's flow waveform processor."), QObject::tr("UF2"), STR_UNIT_EventsPerHour, DEFAULT, QColor(0xa0,0xa0,0xc0)));
+ QObject::tr("User Flag #2"),QObject::tr("A user definable event detected by OSCAR's flow waveform processor."), QObject::tr("UF2"), STR_UNIT_EventsPerHour, DEFAULT, QColor(0xa0,0xa0,0xc0)));
schema::channel.add(GRP_CPAP, new Channel(CPAP_UserFlag3 = 0x1024, FLAG, MT_CPAP, SESSION, "UserFlag3",
- QObject::tr("User Flag #3"),QObject::tr("A user definable event detected by OSCR's flow waveform processor."), QObject::tr("UF3"), STR_UNIT_EventsPerHour, DEFAULT, QColor("dark grey")));
+ QObject::tr("User Flag #3"),QObject::tr("A user definable event detected by OSCAR's flow waveform processor."), QObject::tr("UF3"), STR_UNIT_EventsPerHour, DEFAULT, QColor("dark grey")));
// Oximetry
schema::channel.add(GRP_OXI, new Channel(OXI_Pulse = 0x1800, WAVEFORM, MT_OXIMETER, SESSION, "Pulse",
diff --git a/oscar/SleepLib/session.cpp b/oscar/SleepLib/session.cpp
index 52ffa4ba..9615465f 100644
--- a/oscar/SleepLib/session.cpp
+++ b/oscar/SleepLib/session.cpp
@@ -21,7 +21,7 @@
using namespace std;
-// This is the uber important database version for OSCR's internal storage
+// This is the uber important database version for OSCAR's internal storage
// Increment this after stuffing with Session's save & load code.
const quint16 summary_version = 18;
const quint16 events_version = 10;
diff --git a/oscar/UpdaterWindow.cpp b/oscar/UpdaterWindow.cpp
index 9cc9f80c..e3e5cbfa 100644
--- a/oscar/UpdaterWindow.cpp
+++ b/oscar/UpdaterWindow.cpp
@@ -124,7 +124,7 @@ void UpdaterWindow::checkForUpdates()
}
}
- mainwin->Notify(tr("Checking for OSCR Updates"));
+ mainwin->Notify(tr("Checking for OSCAR Updates"));
#ifdef Q_OS_WIN
update_url = QUrl(QString("http://sleepyhead.jedimark.net/packages/%1/Updates.xml").arg(platform));
@@ -155,7 +155,7 @@ void UpdaterWindow::updateFinished(QNetworkReply *reply)
if (reply->error() != QNetworkReply::NoError) {
qDebug() << "Update Check Error: "+reply->errorString();
disconnect(netmanager, SIGNAL(finished(QNetworkReply *)), this, SLOT(updateFinished(QNetworkReply *)));
- mainwin->Notify(tr("OSCR Updates are currently unvailable for this platform"),tr("OSCR Updates"));
+ mainwin->Notify(tr("OSCAR Updates are currently unvailable for this platform"),tr("OSCAR Updates"));
} else {
QUrl redirectUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
@@ -416,7 +416,7 @@ int compareVersion(QString version)
#ifndef NO_UPDATER
-const QString UPDATE_ROSCR = "com.jedimark.sleepyhead";
+const QString UPDATE_ROSCAR = "com.jedimark.sleepyhead";
const QString UPDATE_QT = "com.jedimark.sleepyhead.qtlibraries";
const QString UPDATE_Translations = "com.jedimark.sleepyhead.translations";
@@ -456,10 +456,10 @@ void UpdaterWindow::ParseLatestVersion(QIODevice *file)
int i=compareVersion(version);
if (i>0) {
- mainwin->Notify(tr("Version %1 of OSCR is available, opening link to download site.").arg(version), STR_TR_OSCR);
- QDesktopServices::openUrl(QUrl(QString("http://nightowlsoftware.ca/OSCR")));
+ mainwin->Notify(tr("Version %1 of OSCAR is available, opening link to download site.").arg(version), STR_TR_OSCAR);
+ QDesktopServices::openUrl(QUrl(QString("http://nightowlsoftware.ca/OSCAR")));
} else {
- mainwin->Notify(tr("You are already running the latest version."), STR_TR_OSCR);
+ mainwin->Notify(tr("You are already running the latest version."), STR_TR_OSCAR);
}
}
@@ -470,7 +470,7 @@ void UpdaterWindow::ParseUpdatesXML(QIODevice *dev)
qDebug() << " XML update structure parsed cleanly";
QHash" + tr("OSCR v%1, codename \"%2\"").arg(release->version).
+ QString html = "
" + tr("OSCAR v%1, codename \"%2\"").arg(release->version).
arg(release->codename) + "
" +
+ notes += "" + tr("OSCAR v%1 build notes").arg(update->version) + "
" +
update->notes.trimmed() + "
";
} else if ((update->type == "qtlibs") && (update->version > QT_VERSION_STR)) {
notes += "" + tr("Update to QtLibs (v%1)").arg(update->version) + "
" +
@@ -909,11 +909,11 @@ void UpdaterWindow::upgradeNext()
if (ok) {
success = true;
- //QMessageBox::information(this,tr("Updates Complete"),tr("OSCR has been updated and needs to restart."),QMessageBox::Ok);
+ //QMessageBox::information(this,tr("Updates Complete"),tr("OSCAR has been updated and needs to restart."),QMessageBox::Ok);
ui->downloadTitle->setText(tr("Update Complete!"));
ui->FinishedButton->setVisible(true);
ui->downloadLabel->setText(
- tr("Updates Complete. OSCR needs to restart now, click Finished to do so."));
+ tr("Updates Complete. OSCAR needs to restart now, click Finished to do so."));
PREF[STR_GEN_UpdatesLastChecked] = QDateTime::currentDateTime();
} else {
ui->downloadTitle->setText(tr("Update Failed :("));
diff --git a/oscar/UpdaterWindow.ui b/oscar/UpdaterWindow.ui
index 1ec247e8..15862317 100644
--- a/oscar/UpdaterWindow.ui
+++ b/oscar/UpdaterWindow.ui
@@ -11,7 +11,7 @@
"
- ""+tr("OSCR v%1").arg(VersionString)+""
+ ""+tr("OSCAR v%1").arg(VersionString)+""
"
";
if (ReleaseStatus != "r") {
text += "
- Due to the lack of documentation released by manufacturers regarding file formats, accuracy of data displayed in OSCR can not in any way be guaranteed.
+ Due to the lack of documentation released by manufacturers regarding file formats, accuracy of data displayed in OSCAR can not in any way be guaranteed.Any reports generated are for PERSONAL USE ONLY, and are NOT IN ANY WAY fit for compliance or medical diagnostic purposes.
@@ -34,10 +34,10 @@- OSCR is free (as in freedom) software, released under the GNU Public License v3, and comes with no warranty, and without ANY claims to fitness for any purpose.
+ OSCAR is free (as in freedom) software, released under the GNU Public License v3, and comes with no warranty, and without ANY claims to fitness for any purpose.- OSCR is copyright ©2011-2018 Mark Watkins
+ OSCAR is copyright ©2011-2018 Mark Watkinsand portions ©2019 Nightowl Software
OSCR Credits
+OSCAR Credits
OSCR is a derivitive of the SleepyHead program written by Mark Watkins, during the years 2011 to 2018. The current project is the combined effort of people from both CPAPtalk.com and ApneaBoard.com, starting in 2019.
-For OSCR to come to you in the form you see it in now, it took a lot more work than just that of the project's original creator Jedimark. The following are the Credits from the last version of SleepyHead.
+OSCAR is a derivitive of the SleepyHead program written by Mark Watkins, during the years 2011 to 2018. The current project is the combined effort of people from both CPAPtalk.com and ApneaBoard.com, starting in 2019.
+For OSCAR to come to you in the form you see it in now, it took a lot more work than just that of the project's original creator Jedimark. The following are the Credits from the last version of SleepyHead.
OpenSource Libraries
-OSCR uses the OpenSource version of the Qt cross platform toolkit available from http://qt.io which itself draws from many smaller open source libraries. You can read the individual licensing for many of these components that are used under the hood of ROSCR at http://doc.qt.io/archives/qt-5.7/3rdparty.html
+OSCAR uses the OpenSource version of the Qt cross platform toolkit available from http://qt.io which itself draws from many smaller open source libraries. You can read the individual licensing for many of these components that are used under the hood of ROSCAR at http://doc.qt.io/archives/qt-5.7/3rdparty.html
Data formats
-Becase the CPAP machine data formats are mostly undocumented and getting them working in OSCR involved a lot of hacking, Mark Watkins needed a lot of SD card data samples, and patient users willing to put up with crashes and wonky data, and plenty of help from my fellow hackers out there who shared in the workload breaking data formats. Thanks to all of you who have helped in the fight to protect our right to keep our own data open and accessible!
Patches, bugfixes and platform support
James Marshall, Rich Freeman, John Masters, Keary Griffin, Patricia Shanahan, Alec Clews, manders99, Sean Stangl, Roy Stone, François Revol, Michael Masterson, RezNet, JediBob, Pholy and names I'm sure I've missed or yet to add.
Becase the CPAP machine data formats are mostly undocumented and getting them working in OSCAR involved a lot of hacking, Mark Watkins needed a lot of SD card data samples, and patient users willing to put up with crashes and wonky data, and plenty of help from my fellow hackers out there who shared in the workload breaking data formats. Thanks to all of you who have helped in the fight to protect our right to keep our own data open and accessible!
Patches, bugfixes and platform support
James Marshall, Rich Freeman, John Masters, Keary Griffin, Patricia Shanahan, Alec Clews, manders99, Sean Stangl, Roy Stone, François Revol, Michael Masterson, RezNet, JediBob, Pholy and names I'm sure I've missed or yet to add.
Language and Translation
Now with sixteen (!) new languages besides English (US) it is important to mention all those people who have done an enormous job breaking their heads over 1566 strings with 9572 words, making a total of over 56.000 characters, for the original SleepyHead Version 1.0.0
-Changes and fixes in OSCR v1.0.0-beta-1
+Changes and fixes in OSCAR v1.0.0-beta-1
" + tr("This software has been created to assist you in reviewing the data produced by CPAP Machines, used in the treatment of various Sleep Disorders.")
+ " " + tr("OSCR has been designed by a software developer with personal experience with a sleep disorder, and shaped by the feedback of many other willing testers dealing with similar conditions.")
+ " " + tr("OSCAR has been designed by a software developer with personal experience with a sleep disorder, and shaped by the feedback of many other willing testers dealing with similar conditions.")
+ " " + tr("This is a beta release, some features may not yet behave as expected.") +
- " "+STR_MessageBox_Warning+": "+tr("For some reason, OSCR does not have any backups for the following machine:")+ " "+STR_MessageBox_Warning+": "+tr("For some reason, OSCAR does not have any backups for the following machine:")+ " "+mach->brand() + " " + mach->model() + " " + mach->modelnumber() + " (" + mach->serial() + ") "+tr("Provided you have made your own backups for ALL of your CPAP data, you can still complete this operation, but you will have to restore from your backups manually.")+" "+tr("Are you really sure you want to do this?")+" "+STR_MessageBox_Warning+": " +
- tr("You are about to obliterate OSCR's machine database for the following machine: "+mach->brand() + " " + mach->model() + " " + mach->modelnumber() + " (" + mach->serial() + ")" + " "+tr("Note as a precaution, the backup folder will be left in place.")+" "+tr("Are you absolutely sure you want to proceed?")+" " + tr("This software is being designed to assist you in reviewing the data produced by your CPAP machines and related equipment.")
+ " " + tr("OSCR has been released freely under the GNU Public License v3, and comes with no warranty, and without ANY claims to fitness for any purpose.")
+ " " + tr("OSCAR has been released freely under the GNU Public License v3, and comes with no warranty, and without ANY claims to fitness for any purpose.")
+ " " + tr("OSCR is intended merely as a data viewer, and definitely not a substitute for competent medical guidance from your Doctor.")
+ " " + tr("OSCAR is intended merely as a data viewer, and definitely not a substitute for competent medical guidance from your Doctor.")
+ " " + tr("Accuracy of any data displayed is not and can not be guaranteed.") + " " + tr("Use of this software is entirely at your own risk.") +
" " + tr("OSCR is copyright ©2011-2018 Mark Watkins and portions ©2019 Nightowl Software") + " " + tr("OSCAR is copyright ©2011-2018 Mark Watkins and portions ©2019 Nightowl Software") + " "
+tr("Pulse Oximeters are medical devices used to measure blood oxygen saturation. During extended Apnea events and abnormal breathing patterns, blood oxygen saturation levels can drop significantly, and can indicate issues that need medical attention.")+" "
- +tr("OSCR gives you the ability to track Oximetry data alongside CPAP session data, which can give valuable insight into the effectiveness of CPAP treatment. It will also work standalone with your Pulse Oximeter, allowing you to store, track and review your recorded data.")+" "
- +tr("OSCR is currently compatible with Contec CMS50D+, CMS50E, CMS50F and CMS50I serial oximeters. "
+tr("You may wish to note, other companies, such as Pulox, simply rebadge Contec CMS50's under new names, such as the Pulox PO-200, PO-300, PO-400. These should also work.")+" "
""+tr("Important Notes:")+" "
- +tr("For OSCR to be able to locate and read directly from your Oximeter device, you need to ensure the correct device drivers (eg. USB to Serial UART) have been installed on your computer. For more information about this, %1click here%2.").arg("").arg("")+" "
+tr("Contec CMS50D+ devices do not have an internal clock, and do not record a starting time. If you do not have a CPAP session to link a recording to, you will have to enter the start time manually after the import process is completed.")+" "
diff --git a/oscar/oximeterimport.ui b/oscar/oximeterimport.ui
index 45e4c6a7..106afe91 100644
--- a/oscar/oximeterimport.ui
+++ b/oscar/oximeterimport.ui
@@ -964,7 +964,7 @@ background: qlineargradient( x1:0 y1:0, x2:1 y2:0, stop:0 white, stop:1 #cccccc)
Please Note: OSCR's advanced session splitting capabilities are not possible with ResMed machines due to a limitation in the way their settings and summary data is stored, and therefore they have been disabled for this profile. On ResMed machines, days will split at noon like in ResMed's commercial software. Please Note: OSCAR's advanced session splitting capabilities are not possible with ResMed machines due to a limitation in the way their settings and summary data is stored, and therefore they have been disabled for this profile. On ResMed machines, days will split at noon like in ResMed's commercial software.
"+
+ QMessageBox::information(nullptr, QObject::tr("A faster build of OSCAR may be available"),
+ QObject::tr("This build of OSCAR is a compatability version that also works on computers lacking OpenGL 2.0 support.")+"
"+
QObject::tr("However it looks like your computer has full support for OpenGL 2.0!") + "
"+
- QObject::tr("This version will run fine, but a \"%1\" tagged build of OSCR will likely run a bit faster on your computer.").arg("-OpenGL")+"
"+
+ QObject::tr("This version will run fine, but a \"%1\" tagged build of OSCAR will likely run a bit faster on your computer.").arg("-OpenGL")+"
"+
QObject::tr("You will not be bothered with this message again."), QMessageBox::Ok, QMessageBox::Ok);
settings.setValue(BetterBuild, true);
}
@@ -166,7 +166,7 @@ int main(int argc, char *argv[])
#else
if (bad_graphics) {
QMessageBox::warning(nullptr, QObject::tr("Incompatible Graphics Hardware"),
- QObject::tr("This build of OSCR requires OpenGL 2.0 support to function correctly, and unfortunately your computer lacks this capability.") + "
"+
+ QObject::tr("This build of OSCAR requires OpenGL 2.0 support to function correctly, and unfortunately your computer lacks this capability.") + "
"+
QObject::tr("You may need to update your computers graphics drivers from the GPU makers website. %1").
arg(intel_graphics ? QObject::tr("(Intel's support site)") : "")+"
"+
QObject::tr("Because graphs will not render correctly, and it may cause crashes, this build will now exit.")+"
"+
@@ -195,9 +195,9 @@ int main(int argc, char *argv[])
if (!havefolder && !force_data_dir) {
if (QMessageBox::question(nullptr, STR_MessageBox_Question,
- QObject::tr("Would you like OSCR to use this location for storing its data?")+"\n\n"+
+ QObject::tr("Would you like OSCAR to use this location for storing its data?")+"\n\n"+
QDir::toNativeSeparators(GetAppRoot())+"\n\n"+
- QObject::tr("If you are upgrading, don't panic, you just need to make sure this is pointed at your old OSCR data folder.")+"\n\n"+
+ QObject::tr("If you are upgrading, don't panic, you just need to make sure this is pointed at your old OSCAR data folder.")+"\n\n"+
QObject::tr("(If you are unsure, just click yes.)"), QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes) {
settings.setValue("Settings/AppRoot", GetAppRoot());
change_data_dir = false;
@@ -208,17 +208,17 @@ retry_directory:
if (change_data_dir) {
QString datadir = QFileDialog::getExistingDirectory(nullptr,
- QObject::tr("Choose or create new folder for OSCR data"), GetAppRoot(),
+ QObject::tr("Choose or create new folder for OSCAR data"), GetAppRoot(),
QFileDialog::ShowDirsOnly);
if (datadir.isEmpty()) {
if (!havefolder) {
QMessageBox::information(nullptr, QObject::tr("Exiting"),
- QObject::tr("As you did not select a data folder, OSCR will exit.")+"\n\n"+QObject::tr("Next time you run, you will be asked again."));
+ QObject::tr("As you did not select a data folder, OSCAR will exit.")+"\n\n"+QObject::tr("Next time you run, you will be asked again."));
return 0;
} else {
QMessageBox::information(nullptr, STR_MessageBox_Warning,
- QObject::tr("You did not select a directory.")+"\n\n"+QObject::tr("OSCR will now start with your old one.")+"\n\n"+
+ QObject::tr("You did not select a directory.")+"\n\n"+QObject::tr("OSCAR will now start with your old one.")+"\n\n"+
QDir::toNativeSeparators(GetAppRoot()), QMessageBox::Ok);
}
} else {
@@ -229,7 +229,7 @@ retry_directory:
if (dir.count() > 2) {
// Not a new directory.. nag the user.
if (QMessageBox::question(nullptr, STR_MessageBox_Warning,
- QObject::tr("The folder you chose is not empty, nor does it already contain valid OSCR data.") +
+ QObject::tr("The folder you chose is not empty, nor does it already contain valid OSCAR data.") +
"\n\n"+QObject::tr("Are you sure you want to use this folder?")+"\n\n" +
datadir, QMessageBox::Yes, QMessageBox::No) == QMessageBox::No) {
goto retry_directory;
@@ -293,7 +293,7 @@ retry_directory:
// check_updates = false;
} else if (vc > 0) {
if (QMessageBox::warning(nullptr, STR_MessageBox_Error,
- QObject::tr("The version of OSCR you just ran is OLDER than the one used to create this data (%1).").
+ QObject::tr("The version of OSCAR you just ran is OLDER than the one used to create this data (%1).").
arg(AppSetting->versionString()) +"\n\n"+
QObject::tr("It is likely that doing this will cause data corruption, are you sure you want to do this?"),
QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::No) {
diff --git a/oscar/mainwindow.cpp b/oscar/mainwindow.cpp
index cc261c02..e030f03d 100644
--- a/oscar/mainwindow.cpp
+++ b/oscar/mainwindow.cpp
@@ -69,7 +69,7 @@ MainWindow::MainWindow(QWidget *parent) :
ui(new Ui::MainWindow)
{
ui->setupUi(this);
- ui->logText->setPlainText("00000: Startup: OSCR Logger initialized");
+ ui->logText->setPlainText("00000: Startup: OSCAR Logger initialized");
if (logger) {
connect(logger, SIGNAL(outputLog(QString)), this, SLOT(logMessage(QString)));
@@ -88,7 +88,7 @@ MainWindow::MainWindow(QWidget *parent) :
systray->show();
systraymenu = new QMenu(this);
systray->setContextMenu(systraymenu);
- QAction *a = systraymenu->addAction(STR_TR_OSCR + " v" + VersionString);
+ QAction *a = systraymenu->addAction(STR_TR_OSCAR + " v" + VersionString);
a->setEnabled(false);
systraymenu->addSeparator();
systraymenu->addAction(tr("&About"), this, SLOT(on_action_About_triggered()));
@@ -105,7 +105,7 @@ MainWindow::MainWindow(QWidget *parent) :
void MainWindow::SetupGUI()
{
QString version = getBranchVersion();
- setWindowTitle(STR_TR_OSCR + QString(" %1").arg(version));
+ setWindowTitle(STR_TR_OSCAR + QString(" %1").arg(version));
#ifdef Q_OS_MAC
@@ -234,7 +234,7 @@ void MainWindow::closeEvent(QCloseEvent * event)
static bool runonce = false;
if (!runonce) {
if (AppSetting->removeCardReminder()) {
- Notify(QObject::tr("Don't forget to place your datacard back in your CPAP machine"), QObject::tr("OSCR Reminder"));
+ Notify(QObject::tr("Don't forget to place your datacard back in your CPAP machine"), QObject::tr("OSCAR Reminder"));
QThread::msleep(1000);
QApplication::processEvents();
}
@@ -279,7 +279,7 @@ void MainWindow::log(QString text)
void MainWindow::Notify(QString s, QString title, int ms)
{
if (title.isEmpty()) {
- title = tr("%1 %2").arg(STR_TR_OSCR).arg(STR_TR_AppVersion);
+ title = tr("%1 %2").arg(STR_TR_OSCAR).arg(STR_TR_AppVersion);
}
if (systray) {
QString msg = s;
@@ -391,8 +391,8 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
if (lockhost.compare(QHostInfo::localHostName()) != 0) {
if (QMessageBox::warning(nullptr, STR_MessageBox_Warning,
QObject::tr("There is a lockfile already present for this profile '%1', claimed on '%2'.").arg(prof->user->userName()).arg(lockhost)+"\n\n"+
- QObject::tr("You can only work with one instance of an individual OSCR profile at a time.")+"\n\n"+
- QObject::tr("If you are using cloud storage, make sure OSCR is closed and syncing has completed first on the other computer before proceeding."),
+ QObject::tr("You can only work with one instance of an individual OSCAR profile at a time.")+"\n\n"+
+ QObject::tr("If you are using cloud storage, make sure OSCAR is closed and syncing has completed first on the other computer before proceeding."),
QMessageBox::Cancel |QMessageBox::Ok, QMessageBox::Cancel) == QMessageBox::Cancel) {
return false;
}
@@ -413,7 +413,7 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
for (QList"
"
"
+ + tr("Welcome to OSCAR") + ""
""
- + tr("Welcome to OSCR") + " "
" "
- " " + tr("About OSCR") + "
"
+ "" + tr("About OSCAR") + "
"
"
" + tr("Please report any bugs you find to the OSCR developer's group.") + "
" + tr("Please report any bugs you find to the OSCAR developer's group.") + ""
"" + tr("Currenly supported machines:") + "
"
"" + tr("CPAP") + ""
@@ -1679,7 +1679,7 @@ void MainWindow::RestartApplication(bool force_login, QString cmdline)
args << "-n"; // -n option is important, as it opens a new process
args << apppath;
- args << "--args"; // OSCR binary options after this
+ args << "--args"; // OSCAR binary options after this
args << "-p"; // -p starts with 1 second delay, to give this process time to save..
@@ -1835,14 +1835,14 @@ void MainWindow::on_actionRebuildCPAP(QAction *action)
tr("Are you sure you want to rebuild all CPAP data for the following machine:\n\n") +
mach->brand() + " " + mach->model() + " " +
mach->modelnumber() + " (" + mach->serial() + ")\n\n" +
- tr("Please note, that this could result in loss of graph data if OSCR's backups have been disabled or interfered with in any way."),
+ tr("Please note, that this could result in loss of graph data if OSCAR's backups have been disabled or interfered with in any way."),
QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::No) {
return;
}
} else {
if (QMessageBox::question(this,
STR_MessageBox_Warning,
- "" + tr("PLEASE READ CAREFULLY") + "
(Note: Direct importing from bluetooth models is probaby not possible yet)")+"
(Note: Direct importing from bluetooth models is probaby not possible yet)")+""
"
"
- "" + STR_TR_OSCR + "
"
+ "" + STR_TR_OSCAR + "
"
"" + tr("Usage Statistics") + "
"
- "" + tr("(NOT approved for compliance or medical reporting purposes)")+"
";
+ "" + tr("(NOT approved for compliance or medical reporting purposes)")+"
";
if (!userinfo.isEmpty()) html += "
"+userinfo+"
";
html += "
";
@@ -652,8 +652,8 @@ QString Statistics::htmlFooter(bool showinfo)
if (showinfo) {
html += "
"
- +tr("OSCR is free open-source CPAP review software");
+ html += tr("This report was generated by OSCAR v%1").arg(ShortVersionString) + "
"
+ +tr("OSCAR is free open-source CPAP review software");
html += "
"+tr("Want more information?")+"
";
- html += ""+tr("OSCR needs all summary data loaded to calculate best/worst data for individual days.")+"
";
+ html += ""+tr("OSCAR needs all summary data loaded to calculate best/worst data for individual days.")+"
";
html += ""+tr("Please enable Pre-Load Summaries checkbox in preferences to make sure this data is available.")+"
";
}
diff --git a/oscar/SleepLib/loader_plugins/prs1_loader.cpp b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
index 90bf8e40..cef5727d 100644
--- a/oscar/SleepLib/loader_plugins/prs1_loader.cpp
+++ b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
@@ -575,7 +575,7 @@ int PRS1Loader::OpenMachine(const QString & path)
QMessageBox::information(QApplication::activeWindow(),
QObject::tr("Non Data Capable Machine"),
QString(QObject::tr("Your Philips Respironics CPAP machine (Model %1) is unfortunately not a data capable model.")+"\n\n"+
- QObject::tr("I'm sorry to report that OSCR can only track hours of use and very basic settings for this machine.")).
+ QObject::tr("I'm sorry to report that OSCAR can only track hours of use and very basic settings for this machine.")).
arg(info.modelnumber),QMessageBox::Ok);
p_profile->cpap->setBrickWarning(false);
@@ -587,7 +587,7 @@ int PRS1Loader::OpenMachine(const QString & path)
QMessageBox::information(QApplication::activeWindow(),
QObject::tr("Machine Unsupported"),
QObject::tr("Sorry, your Philips Respironics CPAP machine (Model %1) is not supported yet.").arg(info.modelnumber) +"\n\n"+
- QObject::tr("The developers needs a .zip copy of this machines' SD card and matching Encore .pdf reports to make it work with OSCR.")
+ QObject::tr("The developers needs a .zip copy of this machines' SD card and matching Encore .pdf reports to make it work with OSCAR.")
,QMessageBox::Ok);
return -1;
@@ -596,8 +596,8 @@ int PRS1Loader::OpenMachine(const QString & path)
// model number didn't parse.. Meh... Silently ignore it
// QMessageBox::information(QApplication::activeWindow(),
// QObject::tr("Machine Unsupported"),
// QObject::tr("OSCR could not parse the model number, this machine can not be imported..") +"\n\n"+
// QObject::tr("The developers needs a .zip copy of this machines' SD card and matching Encore .pdf reports to make it work with OSCR.")
// ,QMessageBox::Ok);
return -1;
}
@@ -596,8 +596,8 @@ int PRS1Loader::OpenMachine(const QString & path)
// QMessageBox::information(QApplication::activeWindow(),
// QObject::tr("Machine Unsupported"),
-// QObject::tr("OSCR could not parse the model number, this machine can not be imported..") +"\n\n"+
-// QObject::tr("The developers needs a .zip copy of this machines' SD card and matching Encore .pdf reports to make it work with OSCR.")
+// QObject::tr("OSCAR could not parse the model number, this machine can not be imported..") +"\n\n"+
+// QObject::tr("The developers needs a .zip copy of this machines' SD card and matching Encore .pdf reports to make it work with OSCAR.")
// ,QMessageBox::Ok);
return -1;